@@ -10,13 +10,12 @@ class InputError(Error):
 
     In most cases, an attempt is made to cast the erroneous input into the
     proper type, and this *Exception* is raised if it fails.
+
+    Parameters
+    ----------
+    message : str
+        A brief description of the mishap detected.
     """
 
-    def __init__(self, message):
-        """Initialise an instance of
-        :class:`~eda_report.exceptions.InputError`.
-
-        :param message: A brief description of the mishap detected.
-        :type message: str
-        """
+    def __init__(self, message) -> None:
         self.message = message
