@@ -28,20 +28,26 @@ class EDAGUI(Frame):  # pragma: no cover
     interface* to the application.
 
     The graphical window is a :class:`tkinter.Frame`, with a brief description
-    of what the application does, and a *button*. Once you click on the button,
-    it launches a *file-dialog* to navigate to and select a file to analyse.
+    of what the application does, and a *button*.
+
+    .. figure:: _static/screencast.*
+       :alt: an image of the graphical user interface
+
+    The button launches a *file-dialog* to navigate to and select a file to
+    analyse.
 
     If a valid file is selected, *text-input widgets* and a *color-picker
     tool* pop up to help set the report's *title*, *target variable(optional)*
-    and *graph color* respectively. Finally, a file-dialog to set the desired
-    location and name for the report is shown.
+    and *graph color*.
 
-    After collecting all the necessary input, the
-    :class:`~eda_report.document.ReportDocument` object is used to create the
-    exploratory data analysis report.
+    Afterwards, a file-dialog to set the desired location and name for the
+    report appears.
+
+    The :class:`~eda_report.document.ReportDocument` object is then used to
+    create the exploratory data analysis report.
     """
 
-    def __init__(self, master=None, **kwargs):
+    def __init__(self, master=None, **kwargs) -> None:
         super().__init__(master)
         self.master.title("eda_report")
         self.master.geometry("600x360")
@@ -50,12 +56,11 @@ class EDAGUI(Frame):  # pragma: no cover
         self._create_widgets()
         self.pack()
 
-    def _create_widgets(self):
+    def _create_widgets(self) -> None:
         """Creates the widgets for the graphical user interface: A *canvas*
         with the a *background image*, *introductory text*, and a *button* to
         select a file.
         """
-        # Create the canvas
         self.canvas = Canvas(self, width=600, height=400)
 
         # Set background image
@@ -87,7 +92,7 @@ class EDAGUI(Frame):  # pragma: no cover
             default="active",
             bg="teal",
             fg="white",
-            command=self.create_report,
+            command=self._create_report,
             relief="flat",
         )
         self.canvas.create_window(
@@ -106,7 +111,7 @@ class EDAGUI(Frame):  # pragma: no cover
 
         self.canvas.pack()
 
-    def create_report(self):
+    def _create_report(self) -> None:
         """Collects input from the graphical user interface, and uses the
         :class:`~eda_report.document.ReportDocument` object to generate a
         report.
@@ -138,7 +143,7 @@ class EDAGUI(Frame):  # pragma: no cover
             showinfo(message=f"Done! Report saved as {self.save_name!r}.")
             del self.data  # Clear stale data
 
-    def _get_data_from_file(self, retries=1):
+    def _get_data_from_file(self, retries=1) -> None:
         """Creates a file dialog to help navigate to and select a file to
         analyse.
         """
@@ -162,7 +167,7 @@ class EDAGUI(Frame):  # pragma: no cover
         else:
             self.master.quit()  # Quit if no file selected and retry is spent
 
-    def _get_report_title(self):
+    def _get_report_title(self) -> None:
         """Creates a simple dialog to capture text input for the desired
         report title.
         """
@@ -179,18 +184,18 @@ class EDAGUI(Frame):  # pragma: no cover
             else "Exploratory Data Analysis Report"
         )
 
-    def _get_target_variable(self):
+    def _get_target_variable(self) -> None:
         """Inquire about the target variable, and create a text box to
         collect input.
         """
         if askyesno(message="Would you like to specify a target variable?"):
-            target_variable = askstring(
+            self.target_variable = askstring(
                 title="Target Variable",
                 prompt="Please enter the name of the target variable:",
             )
             try:
-                self.target_variable = validate_target_variable(
-                    data=self.data, target_variable=target_variable
+                validate_target_variable(
+                    data=self.data, target_variable=self.target_variable
                 )
             except InputError as error:
                 self.target_variable = None
@@ -200,17 +205,17 @@ class EDAGUI(Frame):  # pragma: no cover
         else:  # If user doesn't wish to supply a target variable
             self.target_variable = None
 
-    def _get_graph_color(self):
+    def _get_graph_color(self) -> None:
         """Creates a graphical color picking tool to help set the desired
         color for the generated graphs.
         """
         # Returns a tuple e.g ((255.99609375, 69.26953125, 0.0), '#ff4500').
         color = askcolor(
-            color="orangered", title="Please select a color for the graphs"
+            color="cyan", title="Please select a color for the graphs"
         )[-1]
         self.graph_color = color if color is not None else "orangered"
 
-    def _get_save_as_name(self):
+    def _get_save_as_name(self) -> None:
         """Create a file dialog to help select a destination folder and file
         name for the generated report.
         """
@@ -221,3 +226,13 @@ class EDAGUI(Frame):  # pragma: no cover
             title="Please select Save As file name",
         )
         self.save_name = save_name if save_name else "eda-report.docx"
+
+
+def run_in_gui() -> None:
+    """Starts the *graphical user interface* to the application.
+
+    This provides the entry point for the ``eda_report`` console script
+    (command).
+    """
+    app = EDAGUI()
+    app.mainloop()
